@@ -1,5 +1,5 @@
 /*
-Copyright (©) 2003-2017 Teus Benschop.
+Copyright (©) 2003-2018 Teus Benschop.
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -156,7 +156,7 @@ void database_maintenance ()
   
   
 #ifdef HAVE_CLOUD
-  database_cache_trim ();
+  database_cache_trim (false);
   sword_logic_trim_modules ();
 #endif
 }
