@@ -1,5 +1,5 @@
 /*
- Copyright (©) 2003-2017 Teus Benschop.
+ Copyright (©) 2003-2018 Teus Benschop.
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -46,7 +46,7 @@ void export_html_book (string bible, int book, bool log)
   
   
   // Filename for the html file.
-  string basename = Export_Logic::baseBookFileName (bible, book);
+  string basename = Export_Logic::baseBookFileName (book);
   string filename = filter_url_create_path (directory, basename + ".html");
   string filecss = filter_url_create_path (directory, "stylesheet.css");
   
