@@ -1,5 +1,5 @@
 /*
- Copyright (©) 2003-2017 Teus Benschop.
+ Copyright (©) 2003-2018 Teus Benschop.
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -37,13 +37,12 @@ public:
   static void scheduleWebIndex (string bible, bool log);
   static void scheduleOnlineBible (string bible, bool log);
   static void scheduleESword (string bible, bool log);
-  static void scheduleQuickBible (string bible, bool log);
   static string mainDirectory ();
   static string bibleDirectory (string bible);
   static string USFMdirectory (string bible, int type);
   static string webDirectory (string bible);
   static string webBackLinkDirectory (string bible);
-  static string baseBookFileName (string bible, int book);
+  static string baseBookFileName (int book);
   static string osisDirectory (string bible);
   static string osisSwordVariantDirectory (string interpreter, int complexity);
   static const int export_needed = 0;
@@ -56,8 +55,7 @@ public:
   static const int export_web_index = 7;
   static const int export_online_bible = 8;
   static const int export_esword = 9;
-  static const int export_quick_bible = 10;
-  static const int export_end = 11;
+  static const int export_end = 10;
 private:
 };
 
