@@ -1,5 +1,5 @@
 /*
- Copyright (©) 2003-2017 Teus Benschop.
+ Copyright (©) 2003-2018 Teus Benschop.
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -46,8 +46,8 @@ void export_text_usfm_book (string bible, int book, bool log)
   
   
   // Filenames for text and usfm.
-  string usfmFilename = filter_url_create_path (usfmDirectory, Export_Logic::baseBookFileName (bible, book) + ".usfm");
-  string textFilename = filter_url_create_path (textDirectory, Export_Logic::baseBookFileName (bible, book) + ".txt");
+  string usfmFilename = filter_url_create_path (usfmDirectory, Export_Logic::baseBookFileName (book) + ".usfm");
+  string textFilename = filter_url_create_path (textDirectory, Export_Logic::baseBookFileName (book) + ".txt");
   
   
   Database_Bibles database_bibles;
