@@ -1,5 +1,5 @@
 /*
- Copyright (©) 2003-2017 Teus Benschop.
+ Copyright (©) 2003-2018 Teus Benschop.
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -42,7 +42,9 @@ string notes_status_1_url ()
 
 bool notes_status_1_acl (void * webserver_request)
 {
-  return Filter_Roles::access_control (webserver_request, Filter_Roles::manager ());
+  // Translator should be able to set the status of a note.
+  // https://github.com/bibledit/cloud/issues/243
+  return Filter_Roles::access_control (webserver_request, Filter_Roles::translator ());
 }
 
 
