@@ -1,5 +1,5 @@
 /*
- Copyright (©) 2003-2017 Teus Benschop.
+ Copyright (©) 2003-2018 Teus Benschop.
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -562,9 +562,19 @@ string resource_external_get_net_bible (int book, int chapter, int verse)
   string notes = resource_logic_web_or_cache_get (url, error);
   // If notes fail with an error, don't include the note text.
   if (!error.empty ()) notes.clear ();
+
   // It the verse contains no notes, the website returns an unusual message.
   if (notes.find ("We are currently offline") != string::npos) notes.clear ();
-  
+
+  // Deal with the following message:
+  // Warning Message
+  // An error was detected which prevented the loading of this page. If this problem persists, please contact the website administrator.
+  // libraries/DB_Bible.php [780]:
+  // Invalid argument supplied for foreach()
+  // Loaded in 0.0303 seconds, using 0.59MB of memory. Generated by Kohana v2.3.4.
+  // This error contains so much additional code, that the entire Bibledit program gets confused.
+  if (notes.find ("Warning Message") != string::npos) notes.clear ();
+
   // The "bibleref" class experiences interference from other resources,
   // so that the reference would become invisible.
   // Remove this class, and the references will remain visible.
