@@ -1,5 +1,5 @@
 /*
-Copyright (©) 2003-2017 Teus Benschop.
+Copyright (©) 2003-2018 Teus Benschop.
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -61,7 +61,6 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 #define EXPORTWEBINDEX "exportwebindex"
 #define EXPORTONLINEBIBLE "exportonlinebible"
 #define EXPORTESWORD "exportesword"
-#define EXPORTQUICKBIBLE "exportquickbible"
 #define HYPHENATE "hyphenate"
 #define SETUPPARATEXT "setupparatext"
 #define SYNCPARATEXT "syncparatext"
@@ -83,6 +82,7 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 #define IMPORTRESOURCESTRANSFERFILE "importresourcestransferfile"
 #define CONVERTCONSULTATIONNOTES "convertconsultationnotes"
 #define DELETECHANGES "deletechanges"
+#define CLEARCACHES "clearcaches"
 
 
 string tasks_logic_folder ();
